@@ -1,7 +1,8 @@
-from ctypes import Union
-from typing import Optional
+from typing import Optional, Union
 
-from . import scheme as rcs_scheme
+from rcs_pydantic import enums
+
+from . import scheme
 
 
 class RcsMessage:
@@ -22,7 +23,7 @@ class RcsMessage:
 
     def __init__(
         self,
-        message_info: rcs_scheme.MessageInfo,
+        message_info: scheme.MessageInfo,
         agency_id: str = "ktbizrcs",
         message_base_id: str = STANDALONE_1,
         service_type: str = "RCSSMS",
@@ -32,11 +33,11 @@ class RcsMessage:
         cdr_id: str = "ktrcs02",
         copy_allowed: bool = True,
         body: Union[
-            rcs_scheme.RcsSMSBody,
-            rcs_scheme.RcsLMSBody,
-            rcs_scheme.RcsMMSBody,
-            rcs_scheme.RcsCHATBody,
-            rcs_scheme.RcsTMPLBody,
+            scheme.RcsSMSBody,
+            scheme.RcsLMSBody,
+            scheme.RcsMMSBody,
+            scheme.RcsCHATBody,
+            scheme.RcsTMPLBody,
         ] = ...,
         buttons: Optional[list] = None,
     ):
@@ -51,20 +52,20 @@ class RcsMessage:
         self.copy_allowed = copy_allowed
         self.body = body
         self.buttons = buttons
-        self.send_info = rcs_scheme.SendInfo(
+        self.send_info = scheme.SendInfo(
             common=self.make_common_info(message_info), rcs=self.make_rcs_info(message_info)
         )
 
-    def make_common_info(self, message_info: rcs_scheme.MessageInfo) -> rcs_scheme.CommonInfo:
-        return rcs_scheme.CommonInfo(
+    def make_common_info(self, message_info: scheme.MessageInfo) -> scheme.CommonInfo:
+        return scheme.CommonInfo(
             msgId=message_info.replyId,
             userContact=message_info.userContact,
             scheduleType=0,
-            msgServiceType=rcs_scheme.MessageServiceTypeEnum.RCS,
+            msgServiceType=enums.MessageServiceTypeEnum.RCS,
         )
 
-    def make_rcs_info(self, message_info: rcs_scheme.MessageInfo) -> rcs_scheme.RcsInfo:
-        rcs_info = rcs_scheme.RcsInfo(
+    def make_rcs_info(self, message_info: scheme.MessageInfo) -> scheme.RcsInfo:
+        rcs_info = scheme.RcsInfo(
             chatbotId=message_info.chatbotId,
             agencyId=self.agency_id,
             messagebaseId=self.message_base_id,
@@ -79,6 +80,7 @@ class RcsMessage:
 
         if self.buttons:
             rcs_info.buttons = self.buttons
+        return rcs_info
 
     def send(self):
         self.send_info
